from invenio_records_resources.services import RecordService
from invenio_records_resources.services import RecordService as InvenioRecordService


class DocumentsService(RecordService):
    """DocumentsRecord service."""
